Module aws_sdk_codecatalyst::error
source · Expand description
All error types that operations can return. Documentation on these types is copied from the model.
Modules
Structs
The request was denied because you don't have sufficient access to perform this action. Verify that you are a member of a role that allows this action.
The request was denied because the requested operation would cause a conflict with the current state of a service resource associated with the request. Another user might have updated the resource. Reload, make sure you have the latest data, and then try again.
CreateAccessToken operation.CreateDevEnvironment operation.CreateProject operation.CreateSourceRepositoryBranch operation.DeleteAccessToken operation.DeleteDevEnvironment operation.GetDevEnvironment operation.GetProject operation.GetSourceRepositoryCloneUrls operation.GetSpace operation.GetSubscription operation.GetUserDetails operation.ListAccessTokens operation.ListDevEnvironments operation.ListEventLogs operation.ListProjects operation.ListSourceRepositories operation.ListSourceRepositoryBranches operation.ListSpaces operation.The request was denied because the specified resource was not found. Verify that the spelling is correct and that you have access to the resource.
The request was denied because one or more resources has reached its limits for the tier the space belongs to. Either reduce the number of resources, or change the tier if applicable.
StartDevEnvironment operation.StartDevEnvironmentSession operation.StopDevEnvironment operation.The request was denied due to request throttling.
UpdateDevEnvironment operation.The request was denied because an input failed to satisfy the constraints specified by the service. Check the spelling and input requirements, and then try again.
VerifySession operation.Enums
CreateAccessToken operation.CreateDevEnvironment operation.CreateProject operation.CreateSourceRepositoryBranch operation.DeleteAccessToken operation.DeleteDevEnvironment operation.GetDevEnvironment operation.GetProject operation.GetSourceRepositoryCloneUrls operation.GetSpace operation.GetSubscription operation.GetUserDetails operation.ListAccessTokens operation.ListDevEnvironments operation.ListEventLogs operation.ListProjects operation.ListSourceRepositories operation.ListSourceRepositoryBranches operation.ListSpaces operation.StartDevEnvironment operation.StartDevEnvironmentSession operation.StopDevEnvironment operation.UpdateDevEnvironment operation.VerifySession operation.